@@ -6,8 +6,8 @@
 
 #include "akonadi_serializer_addressee.h"
 
-#include <AkonadiCore/AbstractDifferencesReporter>
-#include <AkonadiCore/Item>
+#include <Akonadi/AbstractDifferencesReporter>
+#include <Akonadi/Item>
 
 #include "serializer_debug.h"
 #include <KContacts/Addressee>
@@ -75,7 +75,8 @@ void SerializerPluginAddressee::serialize(const Item &item, const QByteArray &la
         return;
     }
 
-    KContacts::Addressee addr, temp;
+    KContacts::Addressee addr;
+    KContacts::Addressee temp;
 
     temp = item.payload<KContacts::Addressee>();
 
