@@ -6,13 +6,13 @@
 
 #include "akonadi_serializer_contactgroup.h"
 
+#include <Akonadi/AbstractDifferencesReporter>
 #include <Akonadi/Contact/ContactGroupExpandJob>
-#include <AkonadiCore/abstractdifferencesreporter.h>
-#include <AkonadiCore/item.h>
+#include <Akonadi/Item>
 
+#include <KContacts/ContactGroup>
+#include <KContacts/ContactGroupTool>
 #include <KLocalizedString>
-#include <kcontacts/contactgroup.h>
-#include <kcontacts/contactgrouptool.h>
 
 #include <qplugin.h>
 
