@@ -1,25 +1,25 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef ABSTRACTEMAILADDRESSSELECTIONDIALOG_H
-#define ABSTRACTEMAILADDRESSSELECTIONDIALOG_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
 #include "emailaddressselectionwidget.h"
 
-#include <QDialog>
 #include <KContacts/Addressee>
-namespace Akonadi {
+#include <QDialog>
+namespace Akonadi
+{
 class AKONADI_CONTACT_EXPORT AbstractEmailAddressSelectionDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit AbstractEmailAddressSelectionDialog(QWidget *parent = nullptr);
-    virtual ~AbstractEmailAddressSelectionDialog();
+    ~AbstractEmailAddressSelectionDialog() override;
 
     /**
      * Returns the list of selected email addresses.
@@ -35,4 +35,3 @@ Q_SIGNALS:
 };
 }
 
-#endif // ABSTRACTEMAILADDRESSSELECTIONDIALOG_H
