@@ -7,6 +7,7 @@
 #include "grantleeprinttest.h"
 #include "grantlee/grantleeprint.h"
 #include <QTest>
+#include <kcontacts_version.h>
 
 GrantleePrintTest::GrantleePrintTest(QObject *parent)
     : QObject(parent)
@@ -39,7 +40,13 @@ void GrantleePrintTest::shouldReturnStringWhenAddContentAndContacts()
     KContacts::Addressee::List lst;
     KContacts::Addressee address;
     address.setName(QStringLiteral("foo1"));
+#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
     address.insertEmail(QStringLiteral("foo@kde.org"), true);
+#else
+    KContacts::Email email(QStringLiteral("foo@kde.org"));
+    email.setPreferred(true);
+    address.addEmail(email);
+#endif
     lst << address;
 
     QCOMPARE(grantleePrint.contactsToHtml(lst), QStringLiteral("foo"));
@@ -51,7 +58,13 @@ void GrantleePrintTest::shouldReturnEmails()
     KContacts::Addressee::List lst;
     KContacts::Addressee address;
     address.setName(QStringLiteral("foo1"));
+#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
     address.insertEmail(QStringLiteral("foo@kde.org"), true);
+#else
+    KContacts::Email email(QStringLiteral("foo@kde.org"));
+    email.setPreferred(true);
+    address.addEmail(email);
+#endif
     lst << address;
     grantleePrint.setTemplateContent(
         QStringLiteral("{% if contacts %}{% for contact in contacts %}{% if contact.name %}{{ contact.name }}{% endif %}{% endfor %}{% endif %}"));
@@ -74,7 +87,7 @@ void GrantleePrintTest::shouldDisplayContactInfo_data()
     QTest::newRow("prefix") << QStringLiteral("prefix") << QStringLiteral("foo-prefix");
     QTest::newRow("department") << QStringLiteral("department") << QStringLiteral("foo-department");
     QTest::newRow("office") << QStringLiteral("office") << QStringLiteral("foo-office");
-    QTest::newRow("profesion") << QStringLiteral("profession") << QStringLiteral("foo-profession");
+    QTest::newRow("profession") << QStringLiteral("profession") << QStringLiteral("foo-profession");
     QTest::newRow("manager") << QStringLiteral("managersName") << QStringLiteral("foo-managersname");
     QTest::newRow("assistant") << QStringLiteral("assistantsName") << QStringLiteral("foo-assistantsname");
     QTest::newRow("spouse") << QStringLiteral("spousesName") << QStringLiteral("foo-spousesname");
@@ -93,7 +106,13 @@ void GrantleePrintTest::shouldDisplayContactInfo()
     address.setGivenName(QStringLiteral("foo-givenname"));
     address.setAdditionalName(QStringLiteral("foo-additionalname"));
     address.setName(QStringLiteral("foo1"));
+#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
     address.insertEmail(QStringLiteral("foo@kde.org"), true);
+#else
+    KContacts::Email email(QStringLiteral("foo@kde.org"));
+    email.setPreferred(true);
+    address.addEmail(email);
+#endif
     address.setOrganization(QStringLiteral("kde"));
     address.insertLang(KContacts::Lang(QStringLiteral("fr")));
     address.setNote(QStringLiteral("foo-note"));
