@@ -6,13 +6,14 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CONTACTEDITOR_H
-#define AKONADI_CONTACTEDITOR_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
 #include <QWidget>
 
+#include <memory>
+
 namespace KContacts
 {
 class Addressee;
@@ -25,6 +26,7 @@ namespace Akonadi
 {
 class Collection;
 class Item;
+class AkonadiContactEditorPrivate;
 
 /**
  * @short An widget to edit contacts in Akonadi.
@@ -172,10 +174,8 @@ Q_SIGNALS:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<AkonadiContactEditorPrivate> const d;
     //@endcond
 };
 }
 
-#endif
