@@ -6,13 +6,14 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CONTACTGROUPEDITOR_H
-#define AKONADI_CONTACTGROUPEDITOR_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
 #include <QWidget>
 
+#include <memory>
+
 namespace KContacts
 {
 class ContactGroup;
@@ -22,6 +23,7 @@ namespace Akonadi
 {
 class Collection;
 class Item;
+class ContactGroupEditorPrivate;
 
 /**
  * @short An widget to edit contact groups in Akonadi.
@@ -138,12 +140,10 @@ private:
     //@cond PRIVATE
     friend class ContactGroupEditorDialog;
 
-    class Private;
-    Private *const d;
+    std::unique_ptr<ContactGroupEditorPrivate> const d;
 
     Q_DISABLE_COPY(ContactGroupEditor)
     //@endcond
 };
 }
 
-#endif
