@@ -11,10 +11,10 @@
 #include "contactgroupeditor.h"
 #include "contactgroupeditor_p.h"
 
+#include <Akonadi/CollectionComboBox>
+#include <Akonadi/Item>
+#include <KContacts/ContactGroup>
 #include <KLocalizedString>
-#include <collectioncombobox.h>
-#include <item.h>
-#include <kcontacts/contactgroup.h>
 
 #include <KConfig>
 #include <KMessageBox>
@@ -28,10 +28,10 @@
 
 using namespace Akonadi;
 
-class Q_DECL_HIDDEN ContactGroupEditorDialog::Private
+class Akonadi::ContactGroupEditorDialogPrivate
 {
 public:
-    Private(ContactGroupEditorDialog *qq, ContactGroupEditorDialog::Mode mode)
+    ContactGroupEditorDialogPrivate(ContactGroupEditorDialog *qq, ContactGroupEditorDialog::Mode mode)
         : q(qq)
         , mMode(mode)
     {
@@ -65,15 +65,15 @@ public:
     ContactGroupEditorDialog *const q;
     CollectionComboBox *mAddressBookBox = nullptr;
     ContactGroupEditor *mEditor = nullptr;
-    ContactGroupEditorDialog::Mode mMode;
+    const ContactGroupEditorDialog::Mode mMode;
     QPushButton *okButton = nullptr;
 };
 
 ContactGroupEditorDialog::ContactGroupEditorDialog(Mode mode, QWidget *parent)
     : QDialog(parent)
-    , d(new Private(this, mode))
+    , d(new ContactGroupEditorDialogPrivate(this, mode))
 {
-    setWindowTitle(mode == CreateMode ? i18n("New Contact Group") : i18n("Edit Contact Group"));
+    setWindowTitle(mode == CreateMode ? i18nc("@title:window", "New Contact Group") : i18nc("@title:window", "Edit Contact Group"));
     auto mainLayout = new QVBoxLayout(this);
 
     auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
@@ -91,7 +91,7 @@ ContactGroupEditorDialog::ContactGroupEditorDialog(Mode mode, QWidget *parent)
     auto mainWidget = new QWidget(this);
 
     auto layout = new QGridLayout(mainWidget);
-    layout->setContentsMargins(0, 0, 0, 0);
+    layout->setContentsMargins({});
 
     d->mEditor = new Akonadi::ContactGroupEditor(mode == CreateMode ? Akonadi::ContactGroupEditor::CreateMode : Akonadi::ContactGroupEditor::EditMode, this);
 
@@ -123,7 +123,6 @@ ContactGroupEditorDialog::ContactGroupEditorDialog(Mode mode, QWidget *parent)
 ContactGroupEditorDialog::~ContactGroupEditorDialog()
 {
     d->writeConfig();
-    delete d;
 }
 
 void ContactGroupEditorDialog::setContactGroup(const Akonadi::Item &group)
@@ -158,7 +157,13 @@ void ContactGroupEditorDialog::slotAccepted()
 
 void ContactGroupEditorDialog::reject()
 {
-    if (KMessageBox::questionYesNo(this, i18nc("@info", "Do you really want to cancel?"), i18nc("@title:window", "Confirmation")) == KMessageBox::Yes) {
+    const int answer = KMessageBox::questionYesNo(this,
+                                                  i18nc("@info", "Do you really want to cancel?"),
+                                                  i18nc("@title:window", "Confirmation"),
+                                                  KGuiItem(i18nc("@action:button", "Cancel Editing"), QStringLiteral("dialog-ok")),
+                                                  KGuiItem(i18nc("@action:button", "Do Not Cancel"), QStringLiteral("dialog-cancel")));
+
+    if (answer == KMessageBox::Yes) {
         QDialog::reject(); // Discard current changes
     }
 }
