@@ -10,7 +10,7 @@
 
 #include "attributes/contactmetadataattribute_p.h"
 
-#include <item.h>
+#include <Akonadi/Item>
 
 using namespace Akonadi;
 
