@@ -10,19 +10,19 @@
 
 #include "contactstreemodel.h"
 
-#include <entitytreemodel.h>
-#include <kcontacts/addressee.h>
-#include <kcontacts/contactgroup.h>
+#include <Akonadi/EntityTreeModel>
+#include <KContacts/Addressee>
+#include <KContacts/ContactGroup>
 
 using namespace Akonadi;
 
 static bool contactMatchesFilter(const KContacts::Addressee &contact, const QString &filterString, ContactsFilterProxyModel::MatchFilterContactFlag flag);
 static bool contactGroupMatchesFilter(const KContacts::ContactGroup &group, const QString &filterString);
 
-class Q_DECL_HIDDEN ContactsFilterProxyModel::Private
+class Akonadi::ContactsFilterProxyModelPrivate
 {
 public:
-    Private()
+    ContactsFilterProxyModelPrivate()
         : flags({})
     {
     }
@@ -35,17 +35,14 @@ public:
 
 ContactsFilterProxyModel::ContactsFilterProxyModel(QObject *parent)
     : QSortFilterProxyModel(parent)
-    , d(new Private)
+    , d(new ContactsFilterProxyModelPrivate)
 {
     // contact names should be sorted correctly
     setSortLocaleAware(true);
     setDynamicSortFilter(true);
 }
 
-ContactsFilterProxyModel::~ContactsFilterProxyModel()
-{
-    delete d;
-}
+ContactsFilterProxyModel::~ContactsFilterProxyModel() = default;
 
 void ContactsFilterProxyModel::setFilterString(const QString &filter)
 {
