@@ -6,15 +6,18 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CONTACTSFILTERPROXYMODEL_H
-#define AKONADI_CONTACTSFILTERPROXYMODEL_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
 #include <QSortFilterProxyModel>
 
+#include <memory>
+
 namespace Akonadi
 {
+class ContactsFilterProxyModelPrivate;
+
 /**
  * @short A proxy model for \a ContactsTreeModel models.
  *
@@ -110,12 +113,10 @@ protected:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<ContactsFilterProxyModelPrivate> const d;
     //@endcond
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(ContactsFilterProxyModel::FilterFlags)
 }
 
-#endif
