@@ -9,8 +9,8 @@
 
 #include "contactstreemodel.h"
 
-#include <kcontacts/addressee.h>
-#include <kcontacts/contactgroup.h>
+#include <KContacts/Addressee>
+#include <KContacts/ContactGroup>
 
 #include <KIconLoader>
 #include <KLocalizedString>
@@ -20,29 +20,26 @@
 
 using namespace Akonadi;
 
-class Q_DECL_HIDDEN ContactsTreeModel::Private
+class Akonadi::ContactsTreeModelPrivate
 {
 public:
-    Private()
+    ContactsTreeModelPrivate()
         : mColumns(ContactsTreeModel::Columns() << ContactsTreeModel::FullName)
         , mIconSize(KIconLoader::global()->currentSize(KIconLoader::Small))
     {
     }
 
-    Columns mColumns;
+    ContactsTreeModel::Columns mColumns;
     const int mIconSize;
 };
 
 ContactsTreeModel::ContactsTreeModel(Monitor *monitor, QObject *parent)
     : EntityTreeModel(monitor, parent)
-    , d(new Private)
+    , d(new ContactsTreeModelPrivate)
 {
 }
 
-ContactsTreeModel::~ContactsTreeModel()
-{
-    delete d;
-}
+ContactsTreeModel::~ContactsTreeModel() = default;
 
 void ContactsTreeModel::setColumns(const Columns &columns)
 {
