@@ -10,17 +10,17 @@
 #include "emailaddressselection.h"
 #include "emailaddressselection_p.h"
 
-#include <kcontacts/contactgroup.h>
-#include <kmime/kmime_header_parsing.h>
+#include <KContacts/ContactGroup>
+#include <KMime/HeaderParsing>
 
 using namespace Akonadi;
 
-EmailAddressSelection::Private::Private()
+EmailAddressSelectionPrivate::EmailAddressSelectionPrivate()
     : QSharedData()
 {
 }
 
-EmailAddressSelection::Private::Private(const Private &other)
+EmailAddressSelectionPrivate::EmailAddressSelectionPrivate(const EmailAddressSelectionPrivate &other)
     : QSharedData(other)
 {
     mName = other.mName;
@@ -29,7 +29,7 @@ EmailAddressSelection::Private::Private(const Private &other)
 }
 
 EmailAddressSelection::EmailAddressSelection()
-    : d(new Private)
+    : d(new EmailAddressSelectionPrivate)
 {
 }
 
