@@ -19,7 +19,7 @@
 #include <grantlee/metatype.h>
 #include <grantlee/templateloader.h>
 
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 
 #include <KColorScheme>
 
@@ -30,7 +30,6 @@
 #include <QLocale>
 #include <QMetaProperty>
 #include <QSet>
-#include <memory>
 
 using namespace KAddressBookGrantlee;
 
@@ -42,10 +41,10 @@ if (property == QLatin1String("scheme")) {
 }
 GRANTLEE_END_LOOKUP
 
-class Q_DECL_HIDDEN GrantleeContactFormatter::Private
+class KAddressBookGrantlee::GrantleeContactFormatterPrivate
 {
 public:
-    Private()
+    GrantleeContactFormatterPrivate()
     {
         KConfig config(QStringLiteral("akonadi_contactrc"));
         KConfigGroup group(&config, QStringLiteral("View"));
@@ -56,7 +55,7 @@ public:
         mTemplateLoader = QSharedPointer<Grantlee::FileSystemTemplateLoader>(new Grantlee::FileSystemTemplateLoader());
     }
 
-    ~Private()
+    ~GrantleeContactFormatterPrivate()
     {
         mTemplateLoader.clear();
     }
@@ -88,15 +87,12 @@ public:
 };
 
 GrantleeContactFormatter::GrantleeContactFormatter()
-    : d(new Private)
+    : d(new GrantleeContactFormatterPrivate)
 {
     Grantlee::registerMetaType<QUrl>();
 }
 
-GrantleeContactFormatter::~GrantleeContactFormatter()
-{
-    delete d;
-}
+GrantleeContactFormatter::~GrantleeContactFormatter() = default;
 
 void GrantleeContactFormatter::setAbsoluteThemePath(const QString &path)
 {
