@@ -11,6 +11,8 @@
 #include "abstractcontactgroupformatter.h"
 #include "akonadi-contact_export.h"
 
+#include <memory>
+
 namespace GrantleeTheme
 {
 class Theme;
@@ -18,6 +20,8 @@ class Theme;
 
 namespace KAddressBookGrantlee
 {
+class GrantleeContactGroupFormatterPrivate;
+
 /**
  * @short A class that formats a contact group as HTML code.
  *
@@ -46,8 +50,7 @@ public:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<GrantleeContactGroupFormatterPrivate> const d;
     //@endcond
 };
 }
