@@ -1,19 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef GRANTLEEPRINT_H
-#define GRANTLEEPRINT_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
 #include <GrantleeTheme/GenericFormatter>
 #include <KContacts/Addressee>
 
-namespace KAddressBookGrantlee {
-
+namespace KAddressBookGrantlee
+{
 /** Grantlee-based contact printing. */
 class AKONADI_CONTACT_EXPORT GrantleePrint : public GrantleeTheme::GenericFormatter
 {
@@ -28,4 +27,3 @@ private:
     void init();
 };
 }
-#endif // GRANTLEEPRINT_H
