@@ -4,16 +4,19 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef ADDEMAILDISPLAYJOB_H
-#define ADDEMAILDISPLAYJOB_H
+#pragma once
 
 #include "akonadi-contact_export.h"
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 #include <KJob>
 
+#include <memory>
+
 namespace Akonadi
 {
 class Item;
+class AddEmailDisplayJobPrivate;
+
 /**
  * @brief The AddEmailDisplayJob class
  * @author Laurent Montel <montel@kde.org>
@@ -38,10 +41,9 @@ Q_SIGNALS:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    friend class AddEmailDisplayJobPrivate;
+    std::unique_ptr<AddEmailDisplayJobPrivate> const d;
     //@endcond
 };
 }
 
-#endif
