@@ -6,15 +6,19 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CONTACTSEARCHJOB_H
-#define AKONADI_CONTACTSEARCHJOB_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
-#include <itemsearchjob.h>
-#include <kcontacts/addressee.h>
+#include <Akonadi/ItemSearchJob>
+#include <KContacts/Addressee>
+
+#include <memory>
+
+namespace Akonadi
+{
+class ContactSearchJobPrivate;
 
-namespace Akonadi {
 /**
  * @short Job that searches for contacts in the Akonadi storage.
  *
@@ -76,17 +80,17 @@ public:
     /**
      * Destroys the contact search job.
      */
-    ~ContactSearchJob();
+    ~ContactSearchJob() override;
 
     /**
      * Describes the criteria that can be searched for.
      */
     enum Criterion {
-        Name,       ///< The name of the contact.
-        Email,      ///< The email address of the contact.
-        NickName,   ///< The nickname of the contact.
+        Name, ///< The name of the contact.
+        Email, ///< The email address of the contact.
+        NickName, ///< The nickname of the contact.
         NameOrEmail, ///< The name or email address of the contact. @since 4.5
-        ContactUid   ///< The global unique identifier of the contact. @since 4.5
+        ContactUid ///< The global unique identifier of the contact. @since 4.5
     };
 
     /**
@@ -95,9 +99,9 @@ public:
      * @since 4.5
      */
     enum Match {
-        ExactMatch,      ///< The result must match exactly the pattern (case sensitive).
+        ExactMatch, ///< The result must match exactly the pattern (case sensitive).
         StartsWithMatch, ///< The result must start with the pattern (case insensitive).
-        ContainsMatch,    ///< The result must contain the pattern (case insensitive).
+        ContainsMatch, ///< The result must contain the pattern (case insensitive).
         ContainsWordBoundaryMatch ///< The result must contain a word starting with the pattern (case insensitive).
     };
 
@@ -129,10 +133,8 @@ public:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<ContactSearchJobPrivate> const d;
     //@endcond
 };
 }
 
-#endif
