@@ -11,8 +11,12 @@
 
 #include <QSortFilterProxyModel>
 
+#include <memory>
+
 namespace Akonadi
 {
+class LeafExtensionProxyModelPrivate;
+
 class LeafExtensionProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
@@ -54,8 +58,7 @@ protected:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<LeafExtensionProxyModelPrivate> const d;
 
     Q_PRIVATE_SLOT(d, void sourceRowsInserted(const QModelIndex &, int, int))
     Q_PRIVATE_SLOT(d, void sourceRowsRemoved(const QModelIndex &, int, int))
