@@ -3,11 +3,12 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef SELECTADDRESSBOOKDIALOG_H
-#define SELECTADDRESSBOOKDIALOG_H
+#pragma once
 
 #include "akonadi-contact_export.h"
-#include <AkonadiWidgets/CollectionDialog>
+#include <Akonadi/CollectionDialog>
+
+#include <memory>
 
 namespace Akonadi
 {
@@ -24,8 +25,7 @@ public:
     ~SelectAddressBookDialog() override;
 
 private:
-    SelectAddressBookDialogPrivate *const d;
+    std::unique_ptr<SelectAddressBookDialogPrivate> const d;
 };
 }
 
-#endif // SELECTADDRESSBOOKDIALOG_H
