@@ -6,15 +6,18 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_STANDARDCONTACTGROUPFORMATTER_H
-#define AKONADI_STANDARDCONTACTGROUPFORMATTER_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
 #include "abstractcontactgroupformatter.h"
 
+#include <memory>
+
 namespace Akonadi
 {
+class StandardContactGroupFormatterPrivate;
+
 /**
  * @short A class that formats a contact group as HTML code.
  *
@@ -57,10 +60,8 @@ public:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<StandardContactGroupFormatterPrivate> const d;
     //@endcond
 };
 }
 
-#endif
