@@ -54,7 +54,7 @@ public:
      */
     virtual void setReadOnly(bool readOnly) = 0;
 
-    virtual Q_REQUIRED_RESULT bool hasNoSavedData() const
+    Q_REQUIRED_RESULT virtual bool hasNoSavedData() const
     {
         return false;
     }
