@@ -10,7 +10,7 @@
 
 using namespace ContactEditor;
 
-class Q_DECL_HIDDEN ContactMetaDataBase::Private
+class ContactEditor::ContactMetaDataBasePrivate
 {
 public:
     int mDisplayNameMode = -1;
@@ -18,14 +18,11 @@ public:
 };
 
 ContactMetaDataBase::ContactMetaDataBase()
-    : d(new Private)
+    : d(new ContactMetaDataBasePrivate)
 {
 }
 
-ContactMetaDataBase::~ContactMetaDataBase()
-{
-    delete d;
-}
+ContactMetaDataBase::~ContactMetaDataBase() = default;
 
 void ContactMetaDataBase::loadMetaData(const QVariantMap &metaData)
 {
