@@ -11,8 +11,12 @@
 #include "contacteditor_export.h"
 #include <QVariant>
 
+#include <memory>
+
 namespace ContactEditor
 {
+class ContactMetaDataBasePrivate;
+
 /**
  * @short A helper class for storing contact specific settings.
  */
@@ -78,8 +82,7 @@ private:
     //@cond PRIVATE
     Q_DISABLE_COPY(ContactMetaDataBase)
 
-    class Private;
-    Private *const d;
+    std::unique_ptr<ContactMetaDataBasePrivate> const d;
     //@endcond
 };
 }
