@@ -22,7 +22,7 @@ class BusinessEditorWidget : public QWidget
     Q_OBJECT
 public:
     explicit BusinessEditorWidget(QWidget *parent = nullptr);
-    ~BusinessEditorWidget();
+    ~BusinessEditorWidget() override;
     void loadContact(const KContacts::Addressee &contact);
     void storeContact(KContacts::Addressee &contact);
     void setReadOnly(bool readOnly);
