@@ -10,11 +10,16 @@
 
 #include "abstractcontacteditorwidget_p.h"
 #include "contacteditor_export.h"
+
+#include <memory>
+
 namespace KContacts
 {
 class Addressee;
 }
 
+class ContactEditorWidgetPrivate;
+
 /**
  * @short A widget for editing a contact.
  *
@@ -64,7 +69,6 @@ public:
     Q_REQUIRED_RESULT bool hasNoSavedData() const override;
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<ContactEditorWidgetPrivate> const d;
 };
 
