@@ -7,8 +7,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef CUSTOMFIELDSLISTDELEGATE_H
-#define CUSTOMFIELDSLISTDELEGATE_H
+#pragma once
 
 #include <QStyledItemDelegate>
 class QAbstractItemView;
@@ -33,8 +32,7 @@ private:
     void setFirstColumnAsCurrent();
     void removeField(int row, QAbstractItemModel *model);
     const QIcon mIcon;
-    QSize mButtonSize;
+    const QSize mButtonSize;
     QAbstractItemView *const mItemView;
 };
 }
-#endif
