@@ -26,7 +26,7 @@ class CustomFieldsWidget : public QWidget
     Q_OBJECT
 public:
     explicit CustomFieldsWidget(QWidget *parent = nullptr);
-    ~CustomFieldsWidget();
+    ~CustomFieldsWidget() override;
     void storeContact(KContacts::Addressee &contact) const;
     void loadContact(const KContacts::Addressee &contact);
 
