@@ -15,7 +15,7 @@ class MailWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit MailWidgetTest(QObject *parent = nullptr);
-    ~MailWidgetTest();
+    ~MailWidgetTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
