@@ -24,7 +24,7 @@ MessagingWidget::MessagingWidget(QWidget *parent)
 {
     auto layout = new QHBoxLayout(this);
     layout->setSpacing(0);
-    layout->setContentsMargins(0, 0, 0, 0);
+    layout->setContentsMargins({});
 
     mMessagingEdit = new PreferredLineEditWidget(this);
     mMessagingEdit->setTrapReturnKey(true);
