@@ -21,9 +21,9 @@ NameEditDialog::NameEditDialog(QWidget *parent)
 {
     setWindowTitle(i18nc("@title:window", "Edit Contact Name"));
 
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
-    auto *layout = new QFormLayout;
+    auto layout = new QFormLayout;
     mainLayout->addLayout(layout);
 
     mPrefixCombo = new KComboBox(this);
@@ -75,7 +75,7 @@ NameEditDialog::NameEditDialog(QWidget *parent)
     mSuffixCombo->addItems(suffixList);
 
     mPrefixCombo->lineEdit()->setFocus();
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
